;--------------------------------------------------------
;ROUTINE TO INTERPOL CORRUPTED OMEGA 128 PIXELS WIDE CUBE
;--------------------------------------------------------

;----------------Modification history--------------------
;03/05/2013 Created  (MV, FA, YD, YL...)
;16/05/2013 Modified (MV)
;------------------------Inputs--------------------------
;-> Require idl save file "omega128_interpol.sav"
;cubnum [string] :  omega cube number [cubnum='1052_2']
;rfin   [float]  :  omega radiance or reflectance (idat, jdat, etc...)
;                   size : (npixel,nwavelengths,nscan)
;------------------------Outputs-------------------------
;rfout :  same as rfin, spatial interpolation of corrupted area 
;-------------------------Use----------------------------
;Can be used directly after readomega.pro with:
;omega128_interpol,strmid(nomfic0,3,6),jdat,jdatnew
;--------------------------------------------------------

pro omega128_interpol,cubnum,rfin,rfout

rfout=rfin

;--------------------------------------------------------
;I Tests to determine if correction is needed
;--------------------------------------------------------
orbit=long(strmid(cubnum,0,4))
if (orbit lt 513 or orbit gt 3283) then begin ;orbit range
    print,'orbit not corrupted'
    goto,fin
endif
npixel=(size(rfout))(1)
nscan=(size(rfout))(3)
if (npixel ne 128) then begin ;128 pixel wide only
    print,'not a 128 pixel cube'
    goto,fin
endif
restore,'omega128_interpol.sav'
wtp=where(cubnum eq cublist) ;cube in list?
if (wtp(0) eq -1) then begin
    print,'cube not in list'
    goto,fin
endif
ilist=wtp(0)
cubtype=cubstatus(ilist)
if (cubtype le 0) then  begin ;parity identified ?
    print,'no correction available (good, corrupted, or unusual cube)'
    goto,fin
endif

;--------------------------------------------------------
;II Interpolation loop
;--------------------------------------------------------
if (cubtype eq 1 or cubtype eq 2) then begin
    if (cubtype eq 1) then begin
        print,'parity 1 : spectel 28 good in odd lines'
        firsteven=28 & firstodd=12 ;first bad
    endif else begin
        print,'parity 2 : spectel 28 good in even lines' 
        firsteven=12 & firstodd=28
    endelse
    even=(indgen((nscan-2)/2)+1)*2 ; even lines
    odd=2*indgen((nscan-1)/2)+1 ; odd lines
    for w=0,10 do begin ;loop on spectral position
        rfout(80:95,firsteven+32*w : firsteven+3+32*w,even)=0.5*(rfout(80:95,firsteven+32*w : firsteven+3+32*w,even+1)+rfout(80:95,firsteven+32*w : firsteven+3+32*w,even-1))
        rfout(80:95,firstodd+32*w : firstodd+3+32*w,odd)=0.5*(rfout(80:95,firstodd+32*w : firstodd+3+32*w,odd+1)+rfout(80:95,firstodd+32*w : firstodd+3+32*w,odd-1))
        rfout(80:95,firsteven+32*w : firsteven+3+32*w,0)=rfout(80:95,firsteven+32*w : firsteven+3+32*w,1)
        if ((nscan/2)*2 eq nscan) then rfout(80:95,firstodd+32*w : firstodd+3+32*w,nscan-1)=rfout(80:95,firstodd+32*w : firstodd+3+32*w,nscan-2) else rfout(80:95,firsteven+32*w : firsteven+3+32*w,nscan-1)=rfout(80:95,firsteven+32*w : firsteven+3+32*w,nscan-2)
    endfor
endif

fin:
end
